@@ -131,6 +131,16 @@ class MultiplyValues(BaseManipulator):
     func = "multiply_values"
 
 
+class ScaleDatasets(BaseManipulator):
+    cardinality = "one-to-one"
+    func = "scale_datasets"
+
+
+class RebinByCuratorCfg(BaseManipulator):
+    cardinality = "one-to-one"
+    func = "rebin_by_curator_cfg"
+
+
 class NormaliseGroup(BaseManipulator):
     cardinality = "one-to-one"
     func = "normalise_group"
